@@ -4,11 +4,10 @@
 # @file         vncproxy.py
 # @author       Rick Kennell <kennell@purdue.edu>
 # @author       John Rosheck <jrosheck@purdue.edu>
-# @copyright    Copyright (c) 2005-2012 Purdue University. All rights reserved.
+# @copyright    Copyright (c) 2005-2012 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2005-2012 Purdue University
-# All rights reserved.
+# Copyright (c) 2005-2012 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -26,7 +25,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# HUBzero is a registered trademark of Purdue University.
+# HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 
 from OpenSSL import SSL
@@ -54,7 +53,7 @@ ssl_vnc_portbase = 4000
 # Load the configuration and override the variables above.
 #=============================================================================
 try:
-  execfile('/etc/hubzero/maxwell.conf')
+  execfile('/etc/mw-client/maxwell.conf')
 except IOError:
   pass
 
@@ -468,7 +467,7 @@ def sighandler(sig,frame):
 # main listener program
 #=========================================================================
 
-openlog("/var/log/hubzero/vncproxy.log")
+openlog("/var/log/vncproxy/vncproxy.log")
 
 signal.signal(signal.SIGHUP, sighandler)
 signal.signal(signal.SIGINT, sighandler)
